### Name: uncompress
### Title: Uncompress .Z file data
### Aliases: uncompress
### Keywords: file

### ** Examples

library("uncompress")
## Not run: 
##D 
##D ## Example 1 - extracting text data from a .Z file.
##D handle <- file("file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D uncomp_data <- uncompress(data)
##D # At this point you might want to check if uncomp_data is NULL in case the
##D #  file is corrupt.
##D # This is assuming it's Unix-style text (i.e. \n separates lines).
##D # If it's Windows-style text you may need to use "\r\n".
##D lines <- strsplit(rawToChar(uncomp_data), "\n")
##D print(lines)
##D 
##D ## Example 2 - extracting text data from a .Z file at an HTTP host.
##D handle <- url("http://host/path/file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D uncomp_data <- uncompress(data)
##D # At this point you might want to check if uncomp_data is NULL in case the
##D #  file is corrupt.
##D # This is assuming it's Unix-style text (i.e. \n separates lines).
##D # If it's Windows-style text you may need to use "\r\n".
##D lines <- strsplit(rawToChar(uncomp_data), "\n")
##D print(lines)
##D 
##D ## Example 3 - downloading a .Z file, then uncompressing it.
##D # Mode is important, in Windows if you don't use binary mode the compressed
##D #  data will be corrupted.
##D download.file("http://host/path/file.Z", "file.Z", mode="wb")
##D handle <- file("file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D uncomp_data <- uncompress(data)
##D # At this point you might want to check if uncomp_data is NULL in case the
##D #  file is corrupt.
##D # This is assuming it's Unix-style text (i.e. \n separates lines).
##D # If it's Windows-style text you may need to use "\r\n".
##D lines <- strsplit(rawToChar(uncomp_data), "\n")
##D print(lines)
##D 
##D ## Example 4 - downloading a .Z file, writing the uncompressed data to a
##D ##  local file.
##D handle <- url("http://host/path/file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D uncomp_data <- uncompress(data)
##D handle <- file("file.Z", "wb")
##D writeBin(uncomp_data, handle)
##D close(handle)
##D 
## End(Not run)



