### Name: uncompressToLines
### Title: Uncompress data and return it as a string vector
### Aliases: uncompressToLines
### Keywords: file

### ** Examples

library("uncompress")
## Not run: 
##D 
##D ## Example 1 - uncompress a file, then split it into strings by line.
##D handle <- file("file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D text_lines <- uncompressToLines(data)
##D print(text_lines)
##D 
##D ## Example 2 - the same, except does the conversion 1000 lines at a time.
##D ##             Note that this will uncompress all the data for each call!
##D ##             Example 3 is a much better way to do it.
##D handle <- file("file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D start <- 0
##D while( 1 ) {
##D         text_lines <- uncompressToLines(data, start, 1000)
##D         if( length(text_lines) == 0 )
##D                 break;
##D         print(text_lines);
##D         if( length(text_lines) < 1000 )
##D                 break;
##D         start <- start + 1000
##D }
##D 
##D ## Example 3 - Smarter version of Example 2
##D handle <- file("file.Z", "rb")
##D # The size here is arbitrary, it should be large enough for most files,
##D #  adjust as necessary.
##D data <- readBin(handle, "raw", 99999999)
##D close(handle)
##D data <- uncompress(data);
##D start <- 0
##D while( 1 ) {
##D         text_lines <- rawToLines(data, start, 1000)
##D         if( length(text_lines) == 0 )
##D                 break;
##D         print(text_lines);
##D         if( length(text_lines) < 1000 )
##D                 break;
##D         start <- start + 1000
##D }
##D 
## End(Not run)



